@@ -117,6 +117,8 @@ class SyncKohaRowsCommand(BaseCommand):
                 for key in record:
                     if key != "tr_datetime":
                         record[key] = SyncKohaRowsCommand.sanitize(record[key])
+                    if key == "tr_value":
+                        record[key] = int(record[key])
 
         post_rows_req = requests.post(f"{Config.config['target']['url_add']}/{self.add}",
                                       json={
